# Changelog

## [Unreleased](https://github.com/dermatologist/crisp-t/tree/HEAD)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v1.2.2...HEAD)

**Closed issues:**

- Feature request: Improve the CLI scripts using click. [\#60](https://github.com/dermatologist/crisp-t/issues/60)
- Feature request: Improve the cli with Typer. [\#57](https://github.com/dermatologist/crisp-t/issues/57)

**Merged pull requests:**

- Enhance CLI UX with colored output and improved messaging for non-technical users [\#61](https://github.com/dermatologist/crisp-t/pull/61) ([Copilot](https://github.com/apps/copilot-swe-agent))
- Add --import flag synonym for --source and enhance help with data preparation steps [\#56](https://github.com/dermatologist/crisp-t/pull/56) ([Copilot](https://github.com/apps/copilot-swe-agent))
- Bump peter-evans/create-pull-request from 7 to 8 [\#55](https://github.com/dermatologist/crisp-t/pull/55) ([dependabot[bot]](https://github.com/apps/dependabot))
- Bump nvuillam/github-dependents-info from 1.6.3 to 2.0.2 [\#54](https://github.com/dermatologist/crisp-t/pull/54) ([dependabot[bot]](https://github.com/apps/dependabot))
- Add getting started video link to README [\#53](https://github.com/dermatologist/crisp-t/pull/53) ([dermatologist](https://github.com/dermatologist))
- Optimize slow code patterns in text processing and data loading [\#52](https://github.com/dermatologist/crisp-t/pull/52) ([Copilot](https://github.com/apps/copilot-swe-agent))
- Bump actions/checkout from 5 to 6 [\#51](https://github.com/dermatologist/crisp-t/pull/51) ([dependabot[bot]](https://github.com/apps/dependabot))
- Add graph creation and visualization for corpus relationships [\#50](https://github.com/dermatologist/crisp-t/pull/50) ([Copilot](https://github.com/apps/copilot-swe-agent))
- Feature/fix filter 1 [\#48](https://github.com/dermatologist/crisp-t/pull/48) ([dermatologist](https://github.com/dermatologist))
- Feature/parallel 1 [\#47](https://github.com/dermatologist/crisp-t/pull/47) ([dermatologist](https://github.com/dermatologist))
- Add subcommand support, unquoted syntax, and color formatting to --print option [\#46](https://github.com/dermatologist/crisp-t/pull/46) ([Copilot](https://github.com/apps/copilot-swe-agent))
- Update README and add TDABM documentation for multidimensional data v… [\#44](https://github.com/dermatologist/crisp-t/pull/44) ([dermatologist](https://github.com/dermatologist))
- Implement TDABM \(Topological Data Analysis Ball Mapper\) for multidimensional data visualization [\#43](https://github.com/dermatologist/crisp-t/pull/43) ([Copilot](https://github.com/apps/copilot-swe-agent))
- Update deps [\#41](https://github.com/dermatologist/crisp-t/pull/41) ([dermatologist](https://github.com/dermatologist))
- Replace sample CSV with dynamically created temporary CSV for data pr… [\#40](https://github.com/dermatologist/crisp-t/pull/40) ([dermatologist](https://github.com/dermatologist))
- Add LDA Visualization with pyLDAvis, Coherence and Perplexity Metrics [\#39](https://github.com/dermatologist/crisp-t/pull/39) ([Copilot](https://github.com/apps/copilot-swe-agent))
- Add tqdm progress bars for long-running functions [\#37](https://github.com/dermatologist/crisp-t/pull/37) ([Copilot](https://github.com/apps/copilot-swe-agent))
- Add LSTM text classification method to test convergence between text and outcome variables [\#35](https://github.com/dermatologist/crisp-t/pull/35) ([Copilot](https://github.com/apps/copilot-swe-agent))
- Add semantic search based on document list for literature reviews [\#33](https://github.com/dermatologist/crisp-t/pull/33) ([Copilot](https://github.com/apps/copilot-swe-agent))
- Add semantic chunk search for document coding and annotation [\#31](https://github.com/dermatologist/crisp-t/pull/31) ([Copilot](https://github.com/apps/copilot-swe-agent))
- Bump astral-sh/setup-uv from 6 to 7 [\#29](https://github.com/dermatologist/crisp-t/pull/29) ([dependabot[bot]](https://github.com/apps/dependabot))
- Add semantic search with ChromaDB and metadata export functionality [\#28](https://github.com/dermatologist/crisp-t/pull/28) ([Copilot](https://github.com/apps/copilot-swe-agent))
- Add AGENTS.md file with comprehensive instructions for LLM agents [\#26](https://github.com/dermatologist/crisp-t/pull/26) ([Copilot](https://github.com/apps/copilot-swe-agent))
- Update pytest.yml to support multiple OS and extend timeout; revise D… [\#25](https://github.com/dermatologist/crisp-t/pull/25) ([dermatologist](https://github.com/dermatologist))
- Feature/fix ml output 1 [\#24](https://github.com/dermatologist/crisp-t/pull/24) ([dermatologist](https://github.com/dermatologist))
- Feature/demo 1 [\#23](https://github.com/dermatologist/crisp-t/pull/23) ([dermatologist](https://github.com/dermatologist))
- Feature/copilot mcp fix 1 [\#22](https://github.com/dermatologist/crisp-t/pull/22) ([dermatologist](https://github.com/dermatologist))
- Add Linear and Logistic Regression Support to ML Module [\#19](https://github.com/dermatologist/crisp-t/pull/19) ([Copilot](https://github.com/apps/copilot-swe-agent))
- Feature/vibe 1 [\#17](https://github.com/dermatologist/crisp-t/pull/17) ([dermatologist](https://github.com/dermatologist))
- Feature/utils 1 [\#16](https://github.com/dermatologist/crisp-t/pull/16) ([dermatologist](https://github.com/dermatologist))
- Feature/document meta 1 [\#15](https://github.com/dermatologist/crisp-t/pull/15) ([dermatologist](https://github.com/dermatologist))
- Feature/cli 1 [\#14](https://github.com/dermatologist/crisp-t/pull/14) ([dermatologist](https://github.com/dermatologist))
- Implement comprehensive CLI interface and documentation for CRISP-T framework [\#13](https://github.com/dermatologist/crisp-t/pull/13) ([Copilot](https://github.com/apps/copilot-swe-agent))
- Feature/visualize 1 [\#11](https://github.com/dermatologist/crisp-t/pull/11) ([dermatologist](https://github.com/dermatologist))
- Feature/model 2 [\#10](https://github.com/dermatologist/crisp-t/pull/10) ([dermatologist](https://github.com/dermatologist))
- Update GitHub Actions to use actions/checkout@v5 across all workflows [\#9](https://github.com/dermatologist/crisp-t/pull/9) ([dermatologist](https://github.com/dermatologist))
- Feature/uv 1 [\#8](https://github.com/dermatologist/crisp-t/pull/8) ([dermatologist](https://github.com/dermatologist))
- Feature/readme 1 [\#4](https://github.com/dermatologist/crisp-t/pull/4) ([dermatologist](https://github.com/dermatologist))
- Bump astral-sh/setup-uv from 5 to 6 [\#2](https://github.com/dermatologist/crisp-t/pull/2) ([dependabot[bot]](https://github.com/apps/dependabot))

## [v1.2.2](https://github.com/dermatologist/crisp-t/tree/v1.2.2) (2025-12-23)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v1.2.1...v1.2.2)

## [v1.2.1](https://github.com/dermatologist/crisp-t/tree/v1.2.1) (2025-12-01)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v1.2.0...v1.2.1)

## [v1.2.0](https://github.com/dermatologist/crisp-t/tree/v1.2.0) (2025-11-08)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v1.1.1...v1.2.0)

**Implemented enhancements:**

- Feature Request: Add a graph creation and visualization feature. [\#49](https://github.com/dermatologist/crisp-t/issues/49)

## [v1.1.1](https://github.com/dermatologist/crisp-t/tree/v1.1.1) (2025-10-28)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v1.1.0...v1.1.1)

## [v1.1.0](https://github.com/dermatologist/crisp-t/tree/v1.1.0) (2025-10-28)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v1.0.0...v1.1.0)

## [v1.0.0](https://github.com/dermatologist/crisp-t/tree/v1.0.0) (2025-10-26)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v0.9.0...v1.0.0)

**Implemented enhancements:**

- Feature request: Improve the --print command with more options and better display. [\#45](https://github.com/dermatologist/crisp-t/issues/45)

## [v0.9.0](https://github.com/dermatologist/crisp-t/tree/v0.9.0) (2025-10-25)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v0.8.0...v0.9.0)

**Implemented enhancements:**

- Feature Request: Implement Topological Data Analysis Ball Mapper \(TDABM\) [\#42](https://github.com/dermatologist/crisp-t/issues/42)

## [v0.8.0](https://github.com/dermatologist/crisp-t/tree/v0.8.0) (2025-10-22)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v0.7.0...v0.8.0)

**Implemented enhancements:**

- Feature request: LDA output Visualization for text mining [\#38](https://github.com/dermatologist/crisp-t/issues/38)

## [v0.7.0](https://github.com/dermatologist/crisp-t/tree/v0.7.0) (2025-10-21)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v0.6.0...v0.7.0)

**Implemented enhancements:**

- Feature request: Add a progress bar for long running functions. [\#36](https://github.com/dermatologist/crisp-t/issues/36)

## [v0.6.0](https://github.com/dermatologist/crisp-t/tree/v0.6.0) (2025-10-19)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v0.5.0...v0.6.0)

**Implemented enhancements:**

- Feature request: Add LSTM method to ml.py. [\#34](https://github.com/dermatologist/crisp-t/issues/34)

## [v0.5.0](https://github.com/dermatologist/crisp-t/tree/v0.5.0) (2025-10-18)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v0.4.0...v0.5.0)

**Closed issues:**

- Feature request: Semantic Search based on a list of documents [\#32](https://github.com/dermatologist/crisp-t/issues/32)

## [v0.4.0](https://github.com/dermatologist/crisp-t/tree/v0.4.0) (2025-10-15)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v0.3.0...v0.4.0)

**Closed issues:**

- Feature request: Semantic Search for a concept within a document [\#30](https://github.com/dermatologist/crisp-t/issues/30)

## [v0.3.0](https://github.com/dermatologist/crisp-t/tree/v0.3.0) (2025-10-12)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v0.2.0...v0.3.0)

**Implemented enhancements:**

- Feature request: Semantic Search with chromadb and metadata export as dataframe [\#27](https://github.com/dermatologist/crisp-t/issues/27)

## [v0.2.0](https://github.com/dermatologist/crisp-t/tree/v0.2.0) (2025-10-10)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v0.1.0...v0.2.0)

## [v0.1.0](https://github.com/dermatologist/crisp-t/tree/v0.1.0) (2025-10-10)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/b44ec69181fd0c0204a1692c494a2a36e7c4177e...v0.1.0)

**Implemented enhancements:**

- Feature Request: Create an MCP server [\#20](https://github.com/dermatologist/crisp-t/issues/20)
- Feature request: Add Linear and Logistic regression [\#18](https://github.com/dermatologist/crisp-t/issues/18)
- Feature: Command line interface and Documentation. [\#12](https://github.com/dermatologist/crisp-t/issues/12)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
